djenga
======

Useful building blocks for django


Table of contents
=================

1.  [debugging in pycharm / windows](docs/windows_debugging.md)
2.  [celery detail tasks](docs/detail_tasks.md)
    

